Module info

Module info 

Structs

ReserveInfo
On-chain Klend reserve data needed by helpers that interact with reserves (withdraw, invest, redeem).
VaultInfo
On-chain vault data that cannot be derived from PDAs.
VaultReserve
One active vault allocation: a Klend reserve and the lending market it belongs to.

Enums

VaultInfoError
Errors returned when building a VaultInfo.