Structs
- Reserve
Info - On-chain Klend reserve data needed by helpers that interact with reserves (withdraw, invest, redeem).
- Vault
Info - On-chain vault data that cannot be derived from PDAs.
- Vault
Reserve - One active vault allocation: a Klend reserve and the lending market it belongs to.
Enums
- Vault
Info Error - Errors returned when building a
VaultInfo.